==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24ScrollingButton.h <==
// class javax.swing.plaf.basic.BasicTabbedPaneUI$ScrollingButton

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7391d27632d03ad8 javax_swing_AbstractButton
// @dep_class 69f2be1043a99512 javax_swing_JButton
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 8116f47f48e97c09 javax_swing_plaf_basic_BasicArrowButton
// @dep_class b1f7988506f53f96 javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicArrowButton

#include "javax/swing/plaf/basic/BasicArrowButton.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$method$_init$7b568407947d4d32(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *, jint);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_AbstractButton$vmethods	javax_swing_AbstractButton;
	_jc_javax_swing_JButton$vmethods	javax_swing_JButton;
	_jc_javax_swing_plaf_basic_BasicArrowButton$vmethods	javax_swing_plaf_basic_BasicArrowButton;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton;
    _jc_javax_swing_plaf_basic_BasicArrowButton$sub_refs	javax_swing_plaf_basic_BasicArrowButton;
    _jc_javax_swing_JButton$sub_refs	javax_swing_JButton;
    _jc_javax_swing_AbstractButton$sub_refs	javax_swing_AbstractButton;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_AbstractButton$sub_nonrefs	javax_swing_AbstractButton;
    _jc_javax_swing_JButton$sub_nonrefs	javax_swing_JButton;
    _jc_javax_swing_plaf_basic_BasicArrowButton$sub_nonrefs	javax_swing_plaf_basic_BasicArrowButton;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24ScrollingButton.h <==
// class javax.swing.plaf.basic.BasicTabbedPaneUI$ScrollingButton

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7391d27632d03ad8 javax_swing_AbstractButton
// @dep_class 69f2be1043a99512 javax_swing_JButton
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class c353ac796f75eed1 javax_swing_plaf_basic_BasicArrowButton
// @dep_class b1f7988506f53f96 javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicArrowButton

#include "javax/swing/plaf/basic/BasicArrowButton.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$method$_init$7b568407947d4d32(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_AbstractButton$vmethods	javax_swing_AbstractButton;
	_jc_javax_swing_JButton$vmethods	javax_swing_JButton;
	_jc_javax_swing_plaf_basic_BasicArrowButton$vmethods	javax_swing_plaf_basic_BasicArrowButton;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton;
    _jc_javax_swing_plaf_basic_BasicArrowButton$sub_refs	javax_swing_plaf_basic_BasicArrowButton;
    _jc_javax_swing_JButton$sub_refs	javax_swing_JButton;
    _jc_javax_swing_AbstractButton$sub_refs	javax_swing_AbstractButton;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_AbstractButton$sub_nonrefs	javax_swing_AbstractButton;
    _jc_javax_swing_JButton$sub_nonrefs	javax_swing_JButton;
    _jc_javax_swing_plaf_basic_BasicArrowButton$sub_nonrefs	javax_swing_plaf_basic_BasicArrowButton;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingButton_H_ */
